==> ejc-sale-api-3.0.0-20220415.120158-39-sources.jar: com.ejianc.business.sale/salesorder/vo/ProductInfoVO.java <==
package com.ejianc.business.sale.salesorder.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

public class ProductInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long productId; // 产品id
    private String productName; // 产品名称
    private String asphaltSpec; // 沥青规格名称
    private String addCount; // 外加剂名称
    private BigDecimal projectTotle; // 工程产品总数量


    @ReferSerialTransfer(referCode="ProductorInfoRef")
    public Long getProductId() {
        return productId;
    }
    @ReferDeserialTransfer
    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getAsphaltSpec() {
        return asphaltSpec;
    }

    public void setAsphaltSpec(String asphaltSpec) {
        this.asphaltSpec = asphaltSpec;
    }

    public String getAddCount() {
        return addCount;
    }

    public void setAddCount(String addCount) {
        this.addCount = addCount;
    }

    public BigDecimal getProjectTotle() {
        return projectTotle;
    }

    public void setProjectTotle(BigDecimal projectTotle) {
        this.projectTotle = projectTotle;
    }
}

==> ejc-sale-api-3.0.0-20220505.082701-85-sources.jar: com.ejianc.business.sale/salesorder/vo/ProductInfoVO.java <==
package com.ejianc.business.sale.salesorder.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

public class ProductInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long productId; // 产品id
    private String productName; // 产品名称
    private String asphaltSpec; // 沥青规格名称
    private String addCount; // 外加剂名称
    private BigDecimal projectTotle; // 工程产品总数量
    private String transportMethod; // 运输方式


    @ReferSerialTransfer(referCode="ProductorInfoRef")
    public Long getProductId() {
        return productId;
    }
    @ReferDeserialTransfer
    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getAsphaltSpec() {
        return asphaltSpec;
    }

    public void setAsphaltSpec(String asphaltSpec) {
        this.asphaltSpec = asphaltSpec;
    }

    public String getAddCount() {
        return addCount;
    }

    public void setAddCount(String addCount) {
        this.addCount = addCount;
    }

    public BigDecimal getProjectTotle() {
        return projectTotle;
    }

    public void setProjectTotle(BigDecimal projectTotle) {
        this.projectTotle = projectTotle;
    }

    public String getTransportMethod() {
        return transportMethod;
    }

    public void setTransportMethod(String transportMethod) {
        this.transportMethod = transportMethod;
    }
}
